@@ -1,3 +1,7 @@
+from autolens.conf import check_workspace_path
+
+check_workspace_path()
+
 from autoarray import preprocess
 from autoarray.dataset.imaging import Imaging
 from autoarray.dataset.interferometer import Interferometer
@@ -85,4 +89,4 @@ from .pipeline.phase.phase_galaxy import PhaseGalaxy
 from .pipeline.pipeline import PipelineDataset, PipelinePositions
 
 
-__version__ = '1.5.5'
+__version__ = '1.5.9'
