@@ -1,11 +1,11 @@
 import autofit as af
 import autogalaxy as ag
 from astropy import cosmology as cosmo
-from autogalaxy.pipeline.phase import dataset
+from autolens.pipeline.phase import dataset
 from autogalaxy.pipeline.phase.imaging.phase import PhaseAttributes as AgPhaseAttributes
-from autolens.pipeline.phase.settings import PhaseSettingsImaging
+from autolens.dataset import imaging
+from autolens.pipeline.phase.settings import SettingsPhaseImaging
 from autolens.pipeline.phase.imaging.analysis import Analysis
-from autolens.pipeline.phase.imaging.meta_imaging import MetaImaging
 from autolens.pipeline.phase.imaging.result import Result
 from autolens.pipeline.phase.extensions.stochastic_phase import StochasticPhase
 
@@ -28,7 +28,7 @@ class PhaseImaging(dataset.PhaseDataset):
         galaxies=None,
         hyper_image_sky=None,
         hyper_background_noise=None,
-        settings=PhaseSettingsImaging(),
+        settings=SettingsPhaseImaging(),
         cosmology=cosmo.Planck15,
     ):
 
@@ -58,10 +58,6 @@ class PhaseImaging(dataset.PhaseDataset):
 
         self.is_hyper_phase = False
 
-        self.meta_dataset = MetaImaging(
-            settings=settings, model=self.model, is_hyper_phase=False
-        )
-
     def make_phase_attributes(self, analysis):
         return PhaseAttributes(
             cosmology=self.cosmology,
@@ -90,16 +86,16 @@ class PhaseImaging(dataset.PhaseDataset):
         lens : Analysis
             An lens object that the non-linear search calls to determine the fit of a set of values
         """
-        self.meta_dataset.model = self.model
 
-        masked_imaging = self.meta_dataset.masked_dataset_from(
-            dataset=dataset, mask=mask, results=results
+        masked_imaging = imaging.MaskedImaging(
+            imaging=dataset, mask=mask, settings=self.settings.settings_masked_imaging
         )
 
         self.output_phase_info()
 
         analysis = self.Analysis(
             masked_imaging=masked_imaging,
+            settings=self.settings,
             cosmology=self.cosmology,
             image_path=self.search.paths.image_path,
             results=results,
@@ -116,6 +112,8 @@ class PhaseImaging(dataset.PhaseDataset):
         include_regularization=False,
         histogram_samples=500,
         histogram_bins=10,
+        stochastic_method="gaussian",
+        stochastic_sigma=0.0,
     ):
 
         if stochastic_search is None:
@@ -138,6 +136,8 @@ class PhaseImaging(dataset.PhaseDataset):
             model_classes=tuple(model_classes),
             histogram_samples=histogram_samples,
             histogram_bins=histogram_bins,
+            stochastic_method=stochastic_method,
+            stochastic_sigma=stochastic_sigma,
         )
 
     def output_phase_info(self):
@@ -147,14 +147,18 @@ class PhaseImaging(dataset.PhaseDataset):
         with open(file_phase_info, "w") as phase_info:
             phase_info.write("Optimizer = {} \n".format(type(self.search).__name__))
             phase_info.write(
-                "Sub-grid size = {} \n".format(self.meta_dataset.settings.sub_size)
+                "Sub-grid size = {} \n".format(
+                    self.settings.settings_masked_imaging.sub_size
+                )
             )
             phase_info.write(
-                "PSF shape = {} \n".format(self.meta_dataset.settings.psf_shape_2d)
+                "PSF shape = {} \n".format(
+                    self.settings.settings_masked_imaging.psf_shape_2d
+                )
             )
             phase_info.write(
                 "Positions Threshold = {} \n".format(
-                    self.meta_dataset.settings.positions_threshold
+                    self.settings.settings_lens.positions_threshold
                 )
             )
             phase_info.write("Cosmology = {} \n".format(self.cosmology))
