@@ -28,7 +28,7 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
             ),
             source_0=al.GalaxyModel(
-                redshift=1.0, light=phase1.result.model.galaxies.source_0.light
+                redshift=1.0, light=phase1.result.model.galaxies.source_0.setup_light
             ),
             source_1=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
@@ -57,12 +57,12 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
             ),
             source_0=al.GalaxyModel(
                 redshift=1.0,
-                light=phase2.result.model.galaxies.source_0.light,
+                light=phase2.result.model.galaxies.source_0.setup_light,
                 hyper_galaxy=phase2.result.hyper_combined.instance.galaxies.source_0.hyper_galaxy,
             ),
             source_1=al.GalaxyModel(
                 redshift=1.0,
-                light=phase2.result.model.galaxies.source_1.light,
+                light=phase2.result.model.galaxies.source_1.setup_light,
                 hyper_galaxy=phase2.result.hyper_combined.instance.galaxies.source_1.hyper_galaxy,
             ),
         ),
