@@ -1,5 +1,5 @@
 from autolens.fit.plotters import masked_imaging_fit_plotters
-from test_autolens.simulate.imaging import instrument_util
+from test_autolens.simulators.imaging import instrument_util
 
 # In this tutorial, we'll introduce a new pixelization, called an adaptive-pixelization. This pixelization doesn't use
 # uniform grid of rectangular pixels, but instead uses ir'Voronoi' pixels. So, why would we want to do that?
