@@ -29,7 +29,7 @@ print()
 
 visibilities = al.Visibilities.ones(shape_1d=(total_visibilities,))
 uv_wavelengths = np.ones(shape=(total_visibilities, 2))
-noise_map = al.Visibilities.ones(shape_1d=(total_visibilities,))
+noise_map = al.VisibilitiesNoiseMap.ones(shape_1d=(total_visibilities,))
 
 interferometer = al.Interferometer(
     visibilities=visibilities, noise_map=noise_map, uv_wavelengths=uv_wavelengths
