@@ -19,7 +19,7 @@ Each image is generated for up to 5 instruments, VRO, Euclid, HST, HST, Keck AO.
 
 # To simulate each lens, we pass it an instrument and call its simulate function.
 
-instruments = ["vro", "euclid", "hst"]  # , "hst_up", "ao"]
+instruments = ["vro", "euclid", "hst", "hst_up", "ao"]
 
 for instrument in instruments:
 
