@@ -17,7 +17,9 @@ class TestMaskedInterferometer:
             interferometer=interferometer_7,
             visibilities_mask=visibilities_mask_7x2,
             real_space_mask=sub_mask_7x7,
-            transformer_class=al.TransformerDFT,
+            settings=al.SettingsMaskedInterferometer(
+                transformer_class=al.TransformerDFT
+            ),
         )
 
         assert (
@@ -32,11 +34,6 @@ class TestMaskedInterferometer:
             == np.full(fill_value=False, shape=(7, 2))
         ).all()
 
-        assert (
-            masked_interferometer_7.primary_beam.in_2d == (1.0 / 9.0) * np.ones((3, 3))
-        ).all()
-        assert masked_interferometer_7.primary_beam_shape_2d == (3, 3)
-
         assert (
             masked_interferometer_7.interferometer.uv_wavelengths
             == interferometer_7.uv_wavelengths
@@ -61,22 +58,12 @@ class TestMaskedInterferometer:
             interferometer=interferometer_7,
             visibilities_mask=visibilities_mask_7x2,
             real_space_mask=sub_mask_7x7,
-            grid_class=al.Grid,
-            primary_beam_shape_2d=(3, 3),
-            inversion_pixel_limit=20.0,
-            inversion_uses_border=False,
-            inversion_stochastic=True,
-            preload_sparse_grids_of_planes=1,
+            settings=al.SettingsMaskedInterferometer(grid_class=al.Grid),
         )
 
         assert (masked_interferometer_7.grid.in_1d_binned == grid_7x7).all()
         assert (masked_interferometer_7.grid == sub_grid_7x7).all()
 
-        assert masked_interferometer_7.inversion_pixel_limit == 20.0
-        assert masked_interferometer_7.inversion_uses_border == False
-        assert masked_interferometer_7.inversion_stochastic == True
-        assert masked_interferometer_7.preload_sparse_grids_of_planes == 1
-
         grid = al.Grid.from_mask(mask=sub_mask_7x7)
 
         assert (masked_interferometer_7.grid == grid).all()
@@ -86,7 +73,6 @@ class TestMaskedInterferometer:
     ):
         interferometer = al.Interferometer(
             visibilities=al.Visibilities.ones(shape_1d=(19,)),
-            primary_beam=al.Kernel.ones(shape_2d=(7, 7), pixel_scales=1.0),
             noise_map=al.Visibilities.full(fill_value=2.0, shape_1d=(19,)),
             uv_wavelengths=3.0 * np.ones((19, 2)),
         )
@@ -102,8 +88,6 @@ class TestMaskedInterferometer:
             interferometer=interferometer,
             visibilities_mask=visibilities_mask,
             real_space_mask=real_space_mask,
-            primary_beam_shape_2d=(5, 5),
-            positions_threshold=1.0,
         )
 
         assert (masked_interferometer.visibilities.in_1d == np.ones((19, 2))).all()
@@ -112,10 +96,6 @@ class TestMaskedInterferometer:
             masked_interferometer.interferometer.uv_wavelengths
             == 3.0 * np.ones((19, 2))
         ).all()
-        assert (
-            masked_interferometer.primary_beam.in_2d == (1.0 / 25.0) * np.ones((5, 5))
-        ).all()
-        assert masked_interferometer.primary_beam_shape_2d == (5, 5)
 
     def test__modified_noise_map(
         self, noise_map_7x2, interferometer_7, sub_mask_7x7, visibilities_mask_7x2
@@ -125,7 +105,6 @@ class TestMaskedInterferometer:
             interferometer=interferometer_7,
             visibilities_mask=visibilities_mask_7x2,
             real_space_mask=sub_mask_7x7,
-            transformer_class=al.TransformerDFT,
         )
 
         noise_map_7x2[0, 0] = 10.0
